from django.contrib import admin
from django.urls import path, include
from django.conf.urls import url
from .views import (
                    GecoRegisterView, 
                    GecoLoginView)

from rest_auth.views import (
                            LogoutView,
                            PasswordResetConfirmView,
                            PasswordChangeView,
                            PasswordResetView,
                            UserDetailsView)

urlpatterns = [
    url(r'^rest-auth/login/', GecoLoginView.as_view()),
    url(r'^rest-auth/logout/', LogoutView.as_view()),
    url(r'^rest-auth/reset/', PasswordResetView.as_view()),
    url(r'^rest-auth/change/', PasswordChangeView.as_view()),
    url(r'^rest-auth/reset/confirm/', PasswordResetConfirmView.as_view()),
    url(r'^rest-auth/user/', UserDetailsView.as_view()),
    #url(r'^rest-auth/', include('rest_auth.urls')),
    url(r'^rest-auth/registration/', GecoRegisterView.as_view()),

]


from rest_framework import serializers
from django.contrib.auth import get_user_model
from .models import GecoUser
from rest_auth.registration.serializers import RegisterSerializer
import os
from django.conf import settings

#UserModel = get_user_model()

class GecoUserSerializer(serializers.ModelSerializer):
    
    user = serializers.PrimaryKeyRelatedField(many=False, read_only=True)

    class Meta:
        model = GecoUser
        fields = ('project_user')
        read_only_fields = ('user',)

class GecoRegisterSerializer(RegisterSerializer):


    def save(self, request):
        
        data = request.data
        projects_dir = f'{settings.BASE_DIR}/projects'
        print(data)
        if not os.path.exists(projects_dir):
            os.mkdir(projects_dir)

        user_dir = f'{projects_dir}/{data.get("username")}'
        if not os.path.exists(user_dir):
            os.mkdir(user_dir)

        with open(f"{user_dir}/.htaccess", "w") as htaccess:
            htaccess.write('Header set Access-Control-Allow-Origin "*"\nHeader set Access-Control-Allow-Headers "Access-Control-Allow-Headers, Origin,Accept, X-Requested-With, Content-Type, Access-Control-Request-Method, Access-Control-Request-Headers, range')

        print(user_dir)
        user = super().save(request)
        geco_user = GecoUser(user_dir=user_dir, user=user)
        geco_user.save()
        return user


from django.db import models
from django.contrib.auth.models import User
from django.contrib.auth import get_user_model

# Create your models here.
class GecoUser(models.Model):
    
    user = models.OneToOneField(get_user_model(), on_delete=models.CASCADE)
    user_dir = models.CharField(max_length=150, unique=True)


from django.shortcuts import render
from rest_auth.registration.views import RegisterView
from rest_auth.views import LoginView
from rest_framework.response import Response
from rest_framework import status


from .serializers import GecoRegisterSerializer
from .models import GecoUser
# Create your views here.

class GecoRegisterView(RegisterView):

    serializer_class = GecoRegisterSerializer

    def create(self, request, *args, **kwargs):
        serializer = self.get_serializer(data=request.data)
        serializer.is_valid(raise_exception=True)
        user = self.perform_create(serializer)
        
        geco_user = GecoUser.objects.get(user=user)
        user_dir = geco_user.user_dir

        headers = self.get_success_headers(serializer.data)

        response = self.get_response_data(user)
        response['user_dir'] = user_dir
        return Response(response,
                        status=status.HTTP_201_CREATED,
                        headers=headers)


class GecoLoginView(LoginView):

    def get_response(self):
        serializer_class = self.get_response_serializer()


       
        serializer = serializer_class(instance=self.token,
                                        context={'request': self.request})
        geco_user = GecoUser.objects.get(user=self.user)
        user_dir = geco_user.user_dir

        res_data = {k:v for k,v in  serializer.data.items()}
        res_data['user_dir'] = user_dir
        response = Response(res_data, status=status.HTTP_200_OK)
        
        return response


import setuptools

VERSION         = "0.3.0"
PACKAGE_NAME    = "gecoauth"
AUTHOR          = "Lorenzo Borelli"
EMAIL           = "lorenzo.borelli@gecosistema.com"
GITHUB          = "https://github.com/Plutone11011/geco_auth.git"
DESCRIPTION     = "A Django app that extends django-rest-auth."

setuptools.setup(
    name=PACKAGE_NAME,
    version=VERSION,
    author=AUTHOR,
    author_email=EMAIL,
    description=DESCRIPTION,
    long_description=DESCRIPTION,
    url=GITHUB,
    license='MIT',
    packages=setuptools.find_packages(),
    classifiers=(
        "Environment :: Web Environment",
        "Framework :: Django",
        #Framework :: Django :: 3.2 # Replace "X.Y" as appropriate
        "Intended Audience :: Developers",
        "License :: OSI Approved :: BSD License",
        "Operating System :: OS Independent",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3 :: Only",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Topic :: Internet :: WWW/HTTP",
        "Topic :: Internet :: WWW/HTTP :: Dynamic Content"
    ),
    install_requires=[
        "Django",  # Replace "X.Y" as appropriate
        "djangorestframework", 
        "django-rest-auth", 
        "django-allauth"
    ]
)